@@ -9,6 +9,15 @@ from vyxal.elements import *
 from vyxal.helpers import indent_str, uncompress
 from vyxal.lexer import Token, TokenType
 
+NILADIC_TYPES = (
+    TokenType.STRING,
+    TokenType.NUMBER,
+    TokenType.COMPRESSED_NUMBER,
+    TokenType.COMPRESSED_STRING,
+    TokenType.VARIABLE_GET,
+    TokenType.CODEPAGE_NUMBER,
+)
+
 
 def lambda_wrap(
     branch: list[vyxal.structure.Structure],
@@ -21,6 +30,8 @@ def lambda_wrap(
     """
     if len(branch) == 1:
         if isinstance(branch[0], vyxal.structure.GenericStatement):
+            if branch[0].branches[0][0].name in NILADIC_TYPES:
+                return vyxal.structure.Lambda(0, branch)
             return vyxal.structure.Lambda(
                 elements.get(branch[0].branches[0][0].value, ("", 1))[1],
                 branch,
@@ -35,9 +46,13 @@ def lambda_wrap(
         return vyxal.structure.Lambda(1, branch)
 
 
-def transpile(program: str, dict_compress: bool = True) -> str:
+def transpile(
+    program: str,
+    dict_compress: bool = True,
+    variables_as_digraphs: bool = False,
+) -> str:
     return transpile_ast(
-        vyxal.parse.parse(vyxal.lexer.tokenise(program)),
+        vyxal.parse.parse(vyxal.lexer.tokenise(program, variables_as_digraphs)),
         dict_compress=dict_compress,
     )
 
